# add shortcuts to the package's first level

from . import datasets
from .main import *
from .version import __version__
